@@ -3,18 +3,20 @@ knitr::opts_chunk$set(warning = FALSE)
 knitr::opts_chunk$set(message = FALSE)
 
 ## ------------------------------------------------------------------------
-dragons <- DALEX::dragons
+library(DALEX)
+data(dragons)
 head(dragons)
 
 ## ------------------------------------------------------------------------
+# Linear regression
 lm_model <- lm(life_length ~ ., data = dragons)
 
-## ------------------------------------------------------------------------
-library("randomForest")
+# Random forest
+library(randomForest)
 set.seed(59)
 rf_model <- randomForest(life_length ~ ., data = dragons)
 
-## ------------------------------------------------------------------------
+## ----results = 'hide'----------------------------------------------------
 lm_exp <- DALEX::explain(lm_model, label = "lm", data = dragons, y = dragons$life_length)
 rf_exp <- DALEX::explain(rf_model, label = "rf", data = dragons, y = dragons$life_length)
 
@@ -27,6 +29,9 @@ lm_mp
 
 ## ------------------------------------------------------------------------
 plot(lm_mp, rf_mp)
+# alternative:
+# plot_radar(lm_mp, rf_mp, verbose = FALSE)
+
 
 ## ------------------------------------------------------------------------
 new_score <- function(object) sum(sqrt(abs(object$residuals)))
